@@ -389,7 +389,9 @@ class Builder(QMainWindow):
         model["training_data_ohe"] = self.training_features_ohe
         model["important_cols"] = self.important_cols
 
-        with open("./models/{}.model".format(self.name), "wb") as file:
+        # https://stackoverflow.com/questions/9856683/using-pythons-os-path-how-do-i-go-up-one-directory
+        path = os.path.abspath(os.path.join(os.path.dirname(__file__), '..', 'models'))
+        with open("{}/{}".format(path, self.name), "wb") as file:
             pickle.dump(model, file)
 
         QMessageBox.information(self, "Finished", "The model was successfully saved in the 'models' folder.")
