@@ -1,5 +1,6 @@
 import os
 import pickle
+import datetime
 import sys
 
 import pandas as pd
@@ -654,7 +655,8 @@ class Labeler(QMainWindow):
         self.pushButtonNext.setEnabled(True)
 
     def save_results(self):
-        path_save, _ = QFileDialog.getSaveFileName(self, "Save file", "/home", "CSV (*.csv *.CSV)")
+        now = datetime.datetime.now()
+        path_save, _ = QFileDialog.getSaveFileName(self, "Save file", now.strftime("/home/labelled_%y_%m_%d_%H_%M_%S"), "CSV (*.csv *.CSV)")
         if path_save:
             self.__labelling_summary.to_csv(path_save)
             self.__was_exported = True
