@@ -236,7 +236,9 @@ class Preprocessor(QMainWindow):
 
     def __init__(self):
         super().__init__()
-        uic.loadUi("./resilipy/ui/preprocessor.ui", self)
+        dirname = os.path.dirname(__file__)
+        ui = os.path.join(dirname, "../ui/preprocessor.ui")
+        uic.loadUi(ui, self)
 
         self.threadpool = QThreadPool()
 
@@ -262,7 +264,9 @@ class Preprocessor(QMainWindow):
         """
         Reads and sets up the stylesheet.
         """
-        with open("./resilipy/ui/stylesheet.txt") as file:
+        dirname = os.path.dirname(__file__)
+        path = os.path.join(dirname, "../ui/stylesheet.txt")
+        with open(path) as file:
             stylesheet = file.read()
             self.setStyleSheet(stylesheet)
 
