@@ -12,9 +12,8 @@ from sklearn.discriminant_analysis import QuadraticDiscriminantAnalysis
 
 # fill in your classifier in the following line:
 model = XGBClassifier(n_estimators=100, max_depth=8, learning_rate=0.6, booster="gbtree", gamma=0.1, min_child_weight=0.2, reg_alpha=0.2, reg_lambda=0.5)
-# fill in the name of the file in the following line:
-file_name = "XBGClassifier.pkl"
 
-file_path = "../models/pickled_models/"+file_name
-with open(file_path, 'wb') as file:
+# fill in the name of the file in the following line:
+file_name = "../../demo_files/XBGClassifier.pkl"
+with open(file_name, 'wb') as file:
     pickle.dump(model, file)
\ No newline at end of file
